@@ -189,7 +189,7 @@ impl InnerWebView {
             // See https://github.com/MicrosoftEdge/WebView2Feedback/issues/73
             custom_protocol_names.insert(name.clone());
             w.add_web_resource_requested_filter(
-              &format!("https://custom.protocol.{}_*", name),
+              &format!("https://{}.*", name),
               webview2::WebResourceContext::All,
             )?;
           }
@@ -200,8 +200,8 @@ impl InnerWebView {
             let uri = args.get_request()?.get_uri()?;
             // Undo the protocol workaround when giving path to resolver
             let path = uri
-              .replace("https://custom.protocol.", "")
-              .replacen("_", "://", 1);
+              .replace("https://", "")
+              .replacen(".", "://", 1);
             let scheme = path.split("://").next().unwrap();
 
             match (custom_protocols
@@ -254,11 +254,13 @@ impl InnerWebView {
               // See https://github.com/MicrosoftEdge/WebView2Feedback/issues/73
               url_string = url.as_str().replace(
                 &format!("{}://", name),
-                &format!("https://custom.protocol.{}_", name),
+                &format!("https://{}.", name),
               )
             }
             w.navigate(&url_string)?;
           }
+        } else if let Some(html) = attributes.html {
+          w.navigate_to_string(&html)?;
         }
 
         controller.put_is_visible(true)?;
